@@ -13,7 +13,8 @@ class KJob;
 class QString;
 #define IMAP_RESOURCE_IDENTIFIER QStringLiteral("akonadi_imap_resource")
 
-namespace Util {
+namespace Util
+{
 /// Helper to sanely show an error message for a job
 void showJobError(KJob *job);
 
